package com.ruoyi.logistics.controller;

import java.util.List;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.log.annotation.Log;
import com.ruoyi.common.log.enums.BusinessType;
import com.ruoyi.common.security.annotation.RequiresPermissions;
import com.ruoyi.logistics.domain.BizAddressBook;
import com.ruoyi.logistics.service.IBizAddressBookService;
import com.ruoyi.common.core.web.controller.BaseController;
import com.ruoyi.common.core.web.domain.AjaxResult;
import com.ruoyi.common.core.utils.poi.ExcelUtil;
import com.ruoyi.common.core.web.page.TableDataInfo;

/**
 * PC-地址簿管理
 * 
 * @author RuiJing
 * @date 2026-01-29
 */
@RestController
@RequestMapping("/book")
public class BizAddressBookController extends BaseController
{
    @Autowired
    private IBizAddressBookService bizAddressBookService;

    /**
     * 查询地址簿管理列表
     */
    @RequiresPermissions("system:book:list")
    @GetMapping("/list")
    public TableDataInfo list(BizAddressBook bizAddressBook)
    {
        startPage();
        List<BizAddressBook> list = bizAddressBookService.selectBizAddressBookList(bizAddressBook);
        return getDataTable(list);
    }

    /**
     * 导出地址簿管理列表
     */
    @RequiresPermissions("system:book:export")
    @Log(title = "地址簿管理", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, BizAddressBook bizAddressBook)
    {
        List<BizAddressBook> list = bizAddressBookService.selectBizAddressBookList(bizAddressBook);
        ExcelUtil<BizAddressBook> util = new ExcelUtil<BizAddressBook>(BizAddressBook.class);
        util.exportExcel(response, list, "地址簿管理数据");
    }

    /**
     * 获取地址簿管理详细信息
     */
    @RequiresPermissions("system:book:query")
    @GetMapping(value = "/{addressId}")
    public AjaxResult getInfo(@PathVariable("addressId") Long addressId)
    {
        return success(bizAddressBookService.selectBizAddressBookByAddressId(addressId));
    }

    /**
     * 新增地址簿管理
     */
    @RequiresPermissions("system:book:add")
    @Log(title = "地址簿管理", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody BizAddressBook bizAddressBook)
    {
        return toAjax(bizAddressBookService.insertBizAddressBook(bizAddressBook));
    }

    /**
     * 修改地址簿管理
     */
    @RequiresPermissions("system:book:edit")
    @Log(title = "地址簿管理", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody BizAddressBook bizAddressBook)
    {
        return toAjax(bizAddressBookService.updateBizAddressBook(bizAddressBook));
    }

    /**
     * 删除地址簿管理
     */
    @RequiresPermissions("system:book:remove")
    @Log(title = "地址簿管理", businessType = BusinessType.DELETE)
	@DeleteMapping("/{addressIds}")
    public AjaxResult remove(@PathVariable Long[] addressIds)
    {
        return toAjax(bizAddressBookService.deleteBizAddressBookByAddressIds(addressIds));
    }

    /**
     * 获取登录用户默认地址
     */
    @GetMapping("/getDefaultAddress")
    public AjaxResult getDefaultAddress() {
        return success(bizAddressBookService.selectDefaultAddressBook());
    }
}
